==> knative-model-4.12.0-sources.jar: annotations/io/fabric8/knative/eventing/v1/BrokerBuilder.java <==
package io.fabric8.knative.eventing.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class BrokerBuilder extends BrokerFluentImpl<BrokerBuilder> implements VisitableBuilder<Broker,BrokerBuilder> {

    BrokerFluent<?> fluent;
    Boolean validationEnabled;

    public BrokerBuilder() { 
        this(true);
    }


    public BrokerBuilder(Boolean validationEnabled) { 
        this(new Broker(), validationEnabled);
    }


    public BrokerBuilder(BrokerFluent<?> fluent) { 
        this(fluent, true);
    }


    public BrokerBuilder(BrokerFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new Broker(), validationEnabled);
    }


    public BrokerBuilder(BrokerFluent<?> fluent,Broker instance) { 
        this(fluent, instance, true);
    }


    public BrokerBuilder(BrokerFluent<?> fluent,Broker instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withSpec(instance.getSpec()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }


    public BrokerBuilder(Broker instance) { 
        this(instance,true);
    }


    public BrokerBuilder(Broker instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }


    public Broker build() {
        Broker buildable = new Broker(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        BrokerBuilder that = (BrokerBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.3.1-sources.jar: annotations/io/fabric8/knative/eventing/v1/BrokerBuilder.java <==
package io.fabric8.knative.eventing.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class BrokerBuilder extends BrokerFluentImpl<BrokerBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<Broker,BrokerBuilder> {

    BrokerFluent<?> fluent;
    Boolean validationEnabled;

    public BrokerBuilder() {
        this(true);
    }

    public BrokerBuilder(Boolean validationEnabled) {
        this(new Broker(), validationEnabled);
    }

    public BrokerBuilder(BrokerFluent<?> fluent) {
        this(fluent, true);
    }

    public BrokerBuilder(BrokerFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new Broker(), validationEnabled);
    }

    public BrokerBuilder(BrokerFluent<?> fluent,Broker instance) {
        this(fluent, instance, true);
    }

    public BrokerBuilder(BrokerFluent<?> fluent,Broker instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withSpec(instance.getSpec()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public BrokerBuilder(Broker instance) {
        this(instance,true);
    }

    public BrokerBuilder(Broker instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.eventing.v1.EditableBroker build() {
        EditableBroker buildable = new EditableBroker(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        BrokerBuilder that = (BrokerBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
